==> jc-1.4.0.tar.gz: javax/swing/text/DefaultHighlighter__24DefaultHighlightPainter.h <==
// public class javax.swing.text.DefaultHighlighter$DefaultHighlightPainter

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a36bf35ea5faf9c6 javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter
// @dep_class ee9c929c384f62e3 javax_swing_text_LayeredHighlighter__24LayerPainter

// header file dependencies
// @dep_header javax_swing_text_LayeredHighlighter__24LayerPainter

#include "javax/swing/text/LayeredHighlighter__24LayerPainter.h"

#ifndef _JC_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter_H_
#define _JC_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Rectangle$object;
struct _jc_java_awt_Shape$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_text_JTextComponent$object;
struct _jc_javax_swing_text_View$object;

// Typedefs
typedef struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$sub_refs	_jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$sub_refs;
typedef struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$sub_nonrefs	_jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$sub_nonrefs;
typedef struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$refs	_jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$refs;
typedef struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$nonrefs	_jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$nonrefs;
typedef struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$object	_jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$object;

typedef const struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$vmethods	_jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$vmethods;
typedef const struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$vtable	_jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$vtable;
typedef const struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$vtype	_jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$vtype;

// Constructors
extern void _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$method$_init$d42470fc2dba686a(_jc_env *, struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$object *, struct _jc_java_awt_Color$object *);

// Virtual methods
extern struct _jc_java_awt_Color$object *_jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$method$getColor$fc95765e6818f7ee(_jc_env *, struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$object *);
extern void _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$method$paint$bceb5202634bd482(_jc_env *, struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$object *, struct _jc_java_awt_Graphics$object *, jint, jint, struct _jc_object *, struct _jc_javax_swing_text_JTextComponent$object *);
extern void _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$method$paintHighlight$7b42b8bcbaf0c975(_jc_env *, struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$object *, struct _jc_java_awt_Graphics$object *, struct _jc_java_awt_Rectangle$object *);
extern struct _jc_object *_jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$method$paintLayer$5ec0c7bc1ade4ddd(_jc_env *, struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$object *, struct _jc_java_awt_Graphics$object *, jint, jint, struct _jc_object *, struct _jc_javax_swing_text_JTextComponent$object *, struct _jc_javax_swing_text_View$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$method_info$getColor$fc95765e6818f7ee;
extern _jc_method _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$method_info$paint$bceb5202634bd482;
extern _jc_method _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$method_info$paintHighlight$7b42b8bcbaf0c975;
extern _jc_method _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$method_info$paintLayer$5ec0c7bc1ade4ddd;

// Virtual methods structure
struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$vmethods {
	struct _jc_java_awt_Color$object	*(*getColor$fc95765e6818f7ee)(_jc_env *, struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$object *);
	void	(*paint$bceb5202634bd482)(_jc_env *, struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$object *, struct _jc_java_awt_Graphics$object *, jint, jint, struct _jc_object *, struct _jc_javax_swing_text_JTextComponent$object *);
	void	(*paintHighlight$7b42b8bcbaf0c975)(_jc_env *, struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$object *, struct _jc_java_awt_Graphics$object *, struct _jc_java_awt_Rectangle$object *);
	struct _jc_object	*(*paintLayer$5ec0c7bc1ade4ddd)(_jc_env *, struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$object *, struct _jc_java_awt_Graphics$object *, jint, jint, struct _jc_object *, struct _jc_javax_swing_text_JTextComponent$object *, struct _jc_javax_swing_text_View$object *);
};

// Vtable
struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_LayeredHighlighter__24LayerPainter$vmethods	javax_swing_text_LayeredHighlighter__24LayerPainter;
	_jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$vmethods	javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter;
};

// Vtype
struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$vtype {
	_jc_type			type;
	_jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$sub_refs {
	struct _jc_java_awt_Color$object	*color;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$refs {
    _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$sub_refs	javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter;
    _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$sub_refs	javax_swing_text_LayeredHighlighter__24LayerPainter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$sub_nonrefs	javax_swing_text_LayeredHighlighter__24LayerPainter;
    _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$sub_nonrefs	javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter;
};

// Object instance structure
struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$object {
	_jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$vtype	*vtype;
	_jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$vtype _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$class_object;

#endif	/* _JC_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter_H_ */

==> jc-1.4.6.tar.gz: javax/swing/text/DefaultHighlighter__24DefaultHighlightPainter.h <==
// public class javax.swing.text.DefaultHighlighter$DefaultHighlightPainter

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a36bf35ea5faf9c6 javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter
// @dep_class ee9c929c384f62e3 javax_swing_text_LayeredHighlighter__24LayerPainter

// header file dependencies
// @dep_header javax_swing_text_LayeredHighlighter__24LayerPainter

#include "javax/swing/text/LayeredHighlighter__24LayerPainter.h"

#ifndef _JC_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter_H_
#define _JC_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Rectangle$object;
struct _jc_java_awt_Shape$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_text_JTextComponent$object;
struct _jc_javax_swing_text_View$object;

// Typedefs
typedef struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$sub_refs	_jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$sub_refs;
typedef struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$sub_nonrefs	_jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$sub_nonrefs;
typedef struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$refs	_jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$refs;
typedef struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$nonrefs	_jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$nonrefs;
typedef struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$object	_jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$object;

typedef const struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$vmethods	_jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$vmethods;
typedef const struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$vtable	_jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$vtable;
typedef const struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$vtype	_jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$vtype;

// Constructors
extern void _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$method$_init$d42470fc2dba686a(_jc_env *, struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$object *, struct _jc_java_awt_Color$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Color$object *_jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$method$getColor$fc95765e6818f7ee(_jc_env *, struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$method$paint$bceb5202634bd482(_jc_env *, struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$object *, struct _jc_java_awt_Graphics$object *, jint, jint, struct _jc_object *, struct _jc_javax_swing_text_JTextComponent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$method$paintHighlight$7b42b8bcbaf0c975(_jc_env *, struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$object *, struct _jc_java_awt_Graphics$object *, struct _jc_java_awt_Rectangle$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$method$paintLayer$5ec0c7bc1ade4ddd(_jc_env *, struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$object *, struct _jc_java_awt_Graphics$object *, jint, jint, struct _jc_object *, struct _jc_javax_swing_text_JTextComponent$object *, struct _jc_javax_swing_text_View$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$method_info$getColor$fc95765e6818f7ee;
extern _jc_method _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$method_info$paint$bceb5202634bd482;
extern _jc_method _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$method_info$paintHighlight$7b42b8bcbaf0c975;
extern _jc_method _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$method_info$paintLayer$5ec0c7bc1ade4ddd;

// Virtual methods structure
struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$vmethods {
	struct _jc_java_awt_Color$object	*(*getColor$fc95765e6818f7ee)(_jc_env *, struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$object *) _JC_JCNI_ATTR;
	void	(*paint$bceb5202634bd482)(_jc_env *, struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$object *, struct _jc_java_awt_Graphics$object *, jint, jint, struct _jc_object *, struct _jc_javax_swing_text_JTextComponent$object *) _JC_JCNI_ATTR;
	void	(*paintHighlight$7b42b8bcbaf0c975)(_jc_env *, struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$object *, struct _jc_java_awt_Graphics$object *, struct _jc_java_awt_Rectangle$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*paintLayer$5ec0c7bc1ade4ddd)(_jc_env *, struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$object *, struct _jc_java_awt_Graphics$object *, jint, jint, struct _jc_object *, struct _jc_javax_swing_text_JTextComponent$object *, struct _jc_javax_swing_text_View$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_LayeredHighlighter__24LayerPainter$vmethods	javax_swing_text_LayeredHighlighter__24LayerPainter;
	_jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$vmethods	javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter;
};

// Vtype
struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$vtype {
	_jc_type			type;
	_jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$sub_refs {
	struct _jc_java_awt_Color$object	*color;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$refs {
    _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$sub_refs	javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter;
    _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$sub_refs	javax_swing_text_LayeredHighlighter__24LayerPainter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$sub_nonrefs	javax_swing_text_LayeredHighlighter__24LayerPainter;
    _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$sub_nonrefs	javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter;
};

// Object instance structure
struct _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$object {
	_jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$vtype	*vtype;
	_jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$vtype _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter$class_object;

#endif	/* _JC_javax_swing_text_DefaultHighlighter__24DefaultHighlightPainter_H_ */
